==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/FunnelSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { FunnelSliceDataContextDescription } from "./FunnelSliceDataContextDescription";
/**
 * @hidden
 */
export let FunnelSliceDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceDataContextDescriptionMetadata.a == null) {
                FunnelSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceDataContextDescriptionMetadata.c(FunnelSliceDataContextDescriptionMetadata.a);
            }
            if (a.j(FunnelSliceDataContextDescriptionMetadata.a)) {
                return;
            }
            a.y(FunnelSliceDataContextDescriptionMetadata.a);
        }
        static c(a) {
            DataContextDescriptionMetadata.c(a);
            a.item("ItemOutline", "Brush");
        }
        static d(a) {
            FunnelSliceDataContextDescriptionMetadata.b(a);
            a.aa("FunnelSliceDataContext", () => new FunnelSliceDataContextDescription());
            a.z("FunnelSliceDataContext", FunnelSliceDataContextDescriptionMetadata.a);
        }
    }
    FunnelSliceDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelSliceDataContextDescriptionMetadata, 'FunnelSliceDataContextDescriptionMetadata');
    FunnelSliceDataContextDescriptionMetadata.a = null;
    return FunnelSliceDataContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FunnelSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { FunnelSliceDataContextDescription } from "./FunnelSliceDataContextDescription";
/**
 * @hidden
 */
export let FunnelSliceDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceDataContextDescriptionMetadata.a == null) {
                FunnelSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceDataContextDescriptionMetadata.c(FunnelSliceDataContextDescriptionMetadata.a);
            }
            if (a.k(FunnelSliceDataContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(FunnelSliceDataContextDescriptionMetadata.a);
        }
        static c(a) {
            DataContextDescriptionMetadata.c(a);
            a.item("ItemOutline", "Brush");
        }
        static d(a) {
            FunnelSliceDataContextDescriptionMetadata.b(a);
            a.ac("FunnelSliceDataContext", () => new FunnelSliceDataContextDescription());
            a.ab("FunnelSliceDataContext", FunnelSliceDataContextDescriptionMetadata.a);
        }
    }
    FunnelSliceDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelSliceDataContextDescriptionMetadata, 'FunnelSliceDataContextDescriptionMetadata');
    FunnelSliceDataContextDescriptionMetadata.a = null;
    return FunnelSliceDataContextDescriptionMetadata;
})();
